### Partition coefficient function #####
# A. Grech, R. Beaudouin: 04/2017
##############################

##############################
### Units:
# Volumes:          mL
# Masses:           g
###############################

PC_qsar_model = function(a_PC  = 0.78,  # PC between blood and water and logKow
                         b_PC  = 0.82,  # PC between blood and water and logKow
                         
                         e_Bar = 0.05, # Parameter 1 of Nichols et al. 2006
                         
                         a_Bar = 0.74, # Parameter 1 of Bertelsen et 1998
                         b_Bar = 0.72, # Parameter 2 of Bertelsen et 1998
                         c_Bar = 1.00, # Parameter 3 of Bertelsen et 1998
                           
                         log_Kow,
                         
                         water_liver,  water_gonads, water_brain,
                         water_fat,    water_skin,   water_GIT,
                         water_kidney, water_rp,     water_pp,

                         lipids_liver, lipids_gonads, lipids_brain,  lipids_fat,
                         lipids_skin,  lipids_GIT,    lipids_kidney, lipids_rp,
                         lipids_pp,

                         PC_bw, PC_l, PC_go, PC_b, PC_f, PC_s, PC_gi, PC_k, PC_r, PC_p   ){
  

  
#===============================================
# (I.) QSAR Model : partition coefficient between blood and water,
#=============================================== 

  PC_QSAR_blood_water = 10^(a_PC * log_Kow - b_PC)
  
  PC_blood_water = ifelse (is.null(PC_bw), PC_QSAR_blood_water, PC_bw)  

if( log_Kow > 4.04) {
  
  #===============================================
  # (I.) QSAR Model
  # Nichols, J W.; Schultz, I R.; Fitzsimmons, P N.
  # Aquat. Toxicol. 2006, 78, 74-90.
  #=============================================== 
  
  #PC = lipidcontent * Kow + 0.05 * nonlipidcontent * Kow + watercontent
  
  # Calcul des PCs # SU 
  PC_QSAR_liver       = (water_liver   +  lipids_liver  * 10^( log_Kow) +  e_Bar * (1 - lipids_liver  - water_liver ) )/PC_blood_water
  PC_QSAR_gonads      = (water_gonads  +  lipids_gonads * 10^( log_Kow) +  e_Bar * (1 - lipids_gonads - water_gonads) )/PC_blood_water
  PC_QSAR_brain       = (water_brain   +  lipids_brain  * 10^( log_Kow) +  e_Bar * (1 - lipids_brain  - water_brain)  )/PC_blood_water
  PC_QSAR_fat         = (water_fat     +  lipids_fat    * 10^( log_Kow) +  e_Bar * (1 - lipids_fat    - water_fat )   )/PC_blood_water
  PC_QSAR_skin        = (water_skin    +  lipids_skin   * 10^( log_Kow) +  e_Bar * (1 - lipids_skin   - water_skin )  )/PC_blood_water
  PC_QSAR_GIT         = (water_GIT     +  lipids_GIT    * 10^( log_Kow) +  e_Bar * (1 - lipids_GIT    - water_GIT )   )/PC_blood_water
  PC_QSAR_kidney      = (water_kidney  +  lipids_kidney * 10^( log_Kow) +  e_Bar * (1 - lipids_kidney - water_kidney) )/PC_blood_water
  PC_QSAR_rp          = (water_rp      +  lipids_rp     * 10^( log_Kow) +  e_Bar * (1 - lipids_rp     - water_rp )    )/PC_blood_water
  PC_QSAR_pp          = (water_pp      +  lipids_pp     * 10^( log_Kow) +  e_Bar * (1 - lipids_pp     - water_pp )    )/PC_blood_water
  
} else { 
  
  #===============================================
  # (II.) QSAR Model
  # Bertelsen, S. L.; Hoffman, A. D.; Gallinat, C. A.; Elonen, C. M.; Nichols, J. W.
  # Environ. Toxicol. Chem. 1998, 17, 1447-1455.
  #=============================================== 
  
  # Calcul des PCs # SU 
 
  PC_QSAR_liver       = (water_liver   + 10^(a_Bar*log_Kow + b_Bar + c_Bar * log10(lipids_liver )  )) /PC_blood_water
  PC_QSAR_gonads      = (water_gonads  + 10^(a_Bar*log_Kow + b_Bar + c_Bar * log10(lipids_gonads)  )) /PC_blood_water
  PC_QSAR_brain       = (water_brain   + 10^(a_Bar*log_Kow + b_Bar + c_Bar * log10(lipids_brain)   )) /PC_blood_water
  PC_QSAR_fat         = (water_fat     + 10^(a_Bar*log_Kow + b_Bar + c_Bar * log10(lipids_fat)     )) /PC_blood_water
  PC_QSAR_skin        = (water_skin    + 10^(a_Bar*log_Kow + b_Bar + c_Bar * log10(lipids_skin)    )) /PC_blood_water
  PC_QSAR_GIT         = (water_GIT     + 10^(a_Bar*log_Kow + b_Bar + c_Bar * log10(lipids_GIT)     )) /PC_blood_water
  PC_QSAR_kidney      = (water_kidney  + 10^(a_Bar*log_Kow + b_Bar + c_Bar * log10(lipids_kidney)  )) /PC_blood_water
  PC_QSAR_rp          = (water_rp      + 10^(a_Bar*log_Kow + b_Bar + c_Bar * log10(lipids_rp)      )) /PC_blood_water
  PC_QSAR_pp          = (water_pp      + 10^(a_Bar*log_Kow + b_Bar + c_Bar * log10(lipids_pp)      )) /PC_blood_water
}

#===============================================

PC_liver   = ifelse (is.null(PC_l), PC_QSAR_liver, PC_l)
PC_gonads  = ifelse (is.null(PC_go), PC_QSAR_gonads, PC_go)  
PC_brain   = ifelse (is.null(PC_b), PC_QSAR_brain, PC_b)
PC_fat     = ifelse (is.null(PC_f), PC_QSAR_fat, PC_f) 
PC_skin    = ifelse (is.null(PC_s), PC_QSAR_skin, PC_s)
PC_GIT     = ifelse (is.null(PC_gi), PC_QSAR_GIT, PC_gi)   
PC_kidney  = ifelse (is.null(PC_k), PC_QSAR_kidney, PC_k) 
PC_rp      = ifelse (is.null(PC_r), PC_QSAR_rp, PC_r)
PC_pp      = ifelse (is.null(PC_p), PC_QSAR_pp, PC_p) 

return(   c("PC_blood_water" = PC_blood_water,  "PC_liver"   = PC_liver,  "PC_gonads"      = PC_gonads,
            "PC_brain"       = PC_brain,        "PC_fat"     = PC_fat ,   "PC_skin"        = PC_skin,
            "PC_GIT"         = PC_GIT,    "PC_kidney"      = PC_kidney,
            "PC_rp"          = PC_rp,       "PC_pp"          = PC_pp ))
}

