### Model PBPK (rainbow trout / zebrafish / fathead minnows / stickleback) generic #####
# 10/2017
# A. Grech, C.Tebby, C. Brochot, R. Beaudouin.

##############################
### Variable -(Notation)- Units
# Quantity        -(Q_x) - microg 
# Volumes:        -(V_x) - mL
# Time:           -(t)   - d
# Flows:          -(F_x) - mL/d
# Concentrations: -(C_x) - microg/mL
# Masses:         -(BW)  - g
# Lenght:         -(L)   - mm
# Temperature:    -(TC_c)  - Celsius
#     ''          -(TC_k)  - Kelvin
# Density of each tissue is considered equal to 1
###############################



# Arrhenius temperatures function 
KT <- function(T, TR, TA){ exp ( (TA / TR) - (TA / T) ) }


PBPK.model_T_mixture_pKa_urine <- function(t, Initial.Values, Parameters, input.T) { 
  
  with( as.list(c(Initial.Values, Parameters)),{
    
    # Temperature
    TC_k = input.T(t) + 273.15 # (degree K)
    TC_c = input.T(t)          # (degree C)
    
    # body weight : DEB growth model anisomorphic
    DEB_v_t   = DEB_v  * KT(T=TC_k , TR=TR_DEB ,TA=TA) # mm/d 
    DEB_Lm    = DEB_v / (DEB_KM * DEB_g)                # mm  
    DEB_M     = (DEB_EHm / DEB_EHb)^(1/3)               # EHm and EHb = J
    dL        = (DEB_v_t / (3 * (f_cst + DEB_g))) * (f_cst * DEB_M - (L/DEB_Lm)) 
    BW        = a_BW_L *( (L/10)/DEB_shape ) ^ b_BW_L # BW = g; a = g/cm;  L = mm --> /10 = cm
    #  volumes (mL)
    V_art    = sc_blood  * BW  * frac_art_ven
    V_ven	 = sc_blood  * BW  - V_art
    V_liver  = sc_liver  * BW
    V_gonads = sc_gonads * BW
    V_brain  = sc_brain  * BW
    V_fat    = sc_fat    * BW
    V_skin   = sc_skin   * BW
    V_GIT    = sc_GIT    * BW
    V_kidney = sc_kidney * BW
    V_rp	 = sc_rp     * BW
    V_pp     = BW - (V_art + V_ven + V_liver + V_gonads + V_brain + V_fat + V_skin + V_GIT + V_kidney + V_rp)
    
    V_bal    = BW - (V_art + V_ven + V_liver + V_gonads + V_brain + V_fat + V_skin + V_GIT + V_kidney + V_rp + V_pp) # balance
    
    # Blood flow (mL/d)
    F_card_g = F_card_ref * KT(T=TC_k , TR=TR_Fcard,TA=TA)  * (BW/Bw_Fcard_ref)^(-0.1) # cardiac output = mL/d/g
    F_card   = F_card_g * BW # mL/d
    
    F_liver  = frac_liver  * F_card
    F_gonads = frac_gonads * F_card
    F_brain  = frac_brain  * F_card
    F_fat    = frac_fat    * F_card
    F_skin   = frac_skin   * F_card
    F_GIT    = frac_GIT    * F_card
    F_kidney = frac_kidney * F_card
    F_rp	   = frac_rp     * F_card
    F_pp     = F_card - (F_liver + F_gonads + F_brain + F_fat + F_skin + F_GIT + F_kidney + F_rp)
    
    F_bal = F_card - (F_liver + F_gonads + F_brain + F_fat + F_skin + F_GIT + F_kidney + F_rp + F_pp) # balance
    
    # Effective respiratory volume (mL/d)
    V_O2_g = V_O2_ref * KT(T=TC_k, TR=TR_VO2,TA=TA)  * (BW/Bw_VO2_ref)^(-0.1) #mg O2/d/g 
    V_O2   = V_O2_g * BW   # mg O2/d
    
    C_O2_water = ((-0.24 * TC_c + 14.04) * Sat )/10^3    # mg O2/mL
    F_water    = V_O2/ (O2_EE * C_O2_water)              # mL/d
    
    Kx_1         = min (F_water, F_card * PC_blood_water_1)  # mL/d
    Kx_2         = min (F_water, F_card * PC_blood_water_2)  # mL/d
    
    # Concentrations in tissues (microg/g = microg/mL)
    # Concentrations in tissues (microg/g = microg/mL)
    C_art_1    = Q_art_1    / V_art
    C_ven_1    = Q_ven_1    / V_ven
    C_liver_1  = Q_liver_1  / V_liver
    C_gonads_1 = Q_gonads_1 / V_gonads
    C_brain_1  = Q_brain_1  / V_brain
    C_fat_1    = Q_fat_1    / V_fat
    C_skin_1   = Q_skin_1   / V_skin
    C_GIT_1    = Q_GIT_1    / V_GIT
    C_kidney_1 = Q_kidney_1 / V_kidney
    C_rp_1     = Q_rp_1     / V_rp
    C_pp_1     = Q_pp_1     / V_pp
    C_tot_1    = ((Q_art_1 + Q_ven_1 + Q_liver_1 + Q_gonads_1 + Q_brain_1 + Q_fat_1 + Q_skin_1 + Q_GIT_1 + Q_kidney_1 + Q_pp_1 + Q_rp_1)
                  / (V_art + V_ven + V_liver + V_gonads + V_brain + V_fat + V_skin + V_GIT + V_kidney + V_pp + V_rp))
    
    C_art_2    = Q_art_2    / V_art
    C_ven_2    = Q_ven_2    / V_ven
    C_liver_2  = Q_liver_2  / V_liver
    C_gonads_2 = Q_gonads_2 / V_gonads
    C_brain_2  = Q_brain_2  / V_brain
    C_fat_2    = Q_fat_2    / V_fat
    C_skin_2   = Q_skin_2   / V_skin
    C_GIT_2    = Q_GIT_2    / V_GIT
    C_kidney_2 = Q_kidney_2 / V_kidney
    C_rp_2     = Q_rp_2     / V_rp
    C_pp_2     = Q_pp_2     / V_pp
    C_tot_2    = ((Q_art_2 + Q_ven_2 + Q_liver_2 + Q_gonads_2 + Q_brain_2 + Q_fat_2 + Q_skin_2 + Q_GIT_2 + Q_kidney_2 + Q_pp_2 + Q_rp_2)
                  / (V_art + V_ven + V_liver + V_gonads + V_brain + V_fat + V_skin + V_GIT + V_kidney + V_pp + V_rp))
    
    # concentration in the water : exposure --> microg/g = microg/mL
    C_water_1       = Q_water_1 / V_water
    dQ_elim_water_1 = Ke_water_1 * C_water_1 
    C_water_2 =  Q_water_2 / V_water
    dQ_elim_water_2 = Ke_water_2 * C_water_2 
    
    # concentration in urine
    dV_urine        = urine_rate * BW
    C_urine_1  = Q_urine_1  / V_urine
    C_urine_2  = Q_urine_2  / V_urine
    #C_urine_1_neutral = C_urine_1 / (1 + 10^(pH_urine-pKa_1)) / molar_mass_1  # un-inonized molar concentration
    #C_urine_2_neutral = C_urine_2 / (1 + 10^(pKa_2-pH_urine)) / molar_mass_2
    C_urine_1_neutral = C_urine_1 / (1 + 10^(pKa_1-pH_urine)) / molar_mass_1  # un-inonized molar concentration
    C_urine_2_neutral = C_urine_2 / (1 + 10^(pH_urine-pKa_2)) / molar_mass_2
    C_urine_cplx  = Q_cplx  / V_urine * (molar_mass_1 +molar_mass_2)
    C_urine_crystal  = Q_crystal  / V_urine * (molar_mass_1 +molar_mass_2)
    
	# Scaling clearence and excretion constant
	if ( !is.na(Vmax_1)) { Vmax_sc_1        =  Vmax_1 * V_liver  } 
	if ( !is.na(Cl_liver_1)) { Cl_liver_sc_1    = Cl_liver_1 * V_liver }
    rate_plasma_sc_1 = rate_plasma_1 * BW
    if ( !is.na(Vmax_2)) { Vmax_sc_2        =  Vmax_2 * V_liver  } 
    if ( !is.na(Cl_liver_2)) { Cl_liver_sc_2    = Cl_liver_2 * V_liver }
    rate_plasma_sc_2 = rate_plasma_2 * BW
    
    
    Ku_t_1       = Ku_1 * KT(T=TC_k , TR=289.15 ,TA=TA)
    Ke_feces_t_1 = Ke_feces_1 * KT(T=TC_k , TR=289.15 ,TA=TA)
    Ke_bile_t_1  = Ke_bile_1 * KT(T=TC_k , TR=289.15 ,TA=TA)
    Ke_urine_t_1 = Ke_urine_1 * KT(T=TC_k , TR=289.15 ,TA=TA)
    Ku_t_2       = Ku_2 * KT(T=TC_k , TR=289.15 ,TA=TA)
    Ke_feces_t_2 = Ke_feces_2 * KT(T=TC_k , TR=289.15 ,TA=TA)
    Ke_bile_t_2  = Ke_bile_2 * KT(T=TC_k , TR=289.15 ,TA=TA)
    Ke_urine_t_2 = Ke_urine_2 * KT(T=TC_k , TR=289.15 ,TA=TA)
    
	# Excretion
    dQ_feces_1        = Q_lumen_GIT_1 * Ke_feces_t_1
    dQ_excret_gills_1 = Kx_1 * (C_ven_1 * Unbound_fraction_1 / PC_blood_water_1)
    dQ_bile_1         = Ke_bile_t_1 * C_liver_1  - (Q_bile_1 * K_BG_1)
    dQ_urine_1_cplxed = k_cplx * C_urine_1_neutral * C_urine_2_neutral  *molar_mass_1
    dQ_urine_1        = Ke_urine_t_1 * Q_kidney_1 - dQ_urine_1_cplxed# initialized by scenario for urine discharge
    dQ_urine_cum_1    = Ke_urine_t_1 * Q_kidney_1 - dQ_urine_1_cplxed# not initialized 
    dQ_excret_1       = dQ_excret_gills_1 + dQ_urine_cum_1 + dQ_feces_1 
    
    
    # Quantity absorbed : differentials in microg/d
    dQ_admin_gills_1 = Kx_1 * C_water_1         ###Gills
    dQ_lumen_GIT_1   = ( - Ku_t_1 * Q_lumen_GIT_1
                       - Q_lumen_GIT_1 * Ke_feces_t_1
                       + Q_bile_1 * K_BG_1)  ###GIT
    dQ_admin_GIT_1   = 0
    
    # Metabolism
    dQ_met_plasma_1  = ifelse ((Q_ven_1 > rate_plasma_sc_1), rate_plasma_sc_1, Q_ven_1)
    
    dQ_met_liver_1    = ifelse ( is.na(Cl_liver_1),
                        ( ( Vmax_sc_1 *(C_liver_1/PC_liver_1) )/(Km_1 + C_liver_1/PC_liver_1) ), 
                        ( Cl_liver_sc_1 * C_liver_1 / PC_liver_1) )
    
  	dQ_met_1 = dQ_met_plasma_1 + dQ_met_liver_1
    
  	
    # Blood quantity
  	dQ_art_1    = ( F_card * C_ven_1 - F_fat * C_art_1 - F_rp * C_art_1 - F_pp * C_art_1
  	                - F_liver  * C_art_1 - F_kidney * C_art_1   - F_GIT * C_art_1
  	                - F_gonads * C_art_1  - F_skin   * C_art_1 - F_brain  * C_art_1 )
  	
  	dQ_ven_1    = (F_brain * C_brain_1/PC_brain_1
  	               + (F_liver + F_rp + F_gonads + F_GIT ) * C_liver_1/PC_liver_1
  	               +  F_fat   * C_fat_1/PC_fat_1
  	               + (F_kidney + ((1 - a_Fpp) * F_pp) + ((1 - a_Fs) * F_skin)) * (C_kidney_1 / PC_kidney_1)
  	               + a_Fpp * F_pp  * (C_pp_1 / PC_pp_1) 
  	               + a_Fs * F_skin * (C_skin_1 / PC_skin_1)
  	               - F_card * C_ven_1  
  	               + dQ_admin_gills_1 - dQ_excret_gills_1
  	               - dQ_met_plasma_1)
  	
    # Quantity in tissues 
  	dQ_gonads_1 = F_gonads*(C_art_1 - C_gonads_1/PC_gonads_1)
  	dQ_fat_1    = F_fat   *(C_art_1 - C_fat_1/PC_fat_1)
  	dQ_rp_1     = F_rp    *(C_art_1 - C_rp_1/PC_rp_1)
  	dQ_pp_1     = F_pp    *(C_art_1 - C_pp_1/PC_pp_1)
  	dQ_brain_1  = F_brain *(C_art_1 - C_brain_1/PC_brain_1)
  	dQ_skin_1   = F_skin*(C_art_1 - C_skin_1/PC_skin_1)
  	
  	dQ_liver_1  =  ( F_liver * C_art_1  
  	                 + F_rp *(C_rp_1/PC_rp_1)
  	                 + F_GIT *(C_GIT_1/PC_GIT_1)
  	                 + F_gonads*(C_gonads_1/PC_gonads_1)
  	                 - ( F_liver + F_rp + F_GIT + F_gonads  ) *(C_liver_1/PC_liver_1)  
  	                 - (Ke_bile_t_1  * Q_liver_1) - dQ_met_liver_1 )
    
  	dQ_kidney_1 = ( F_kidney * C_art_1 
  	                + (1-a_Fpp) * F_pp * (C_pp_1 / PC_pp_1) 
  	                + (1-a_Fs) * F_skin * (C_skin_1 / PC_skin_1) 
  	                - (F_kidney + (1-a_Fpp) * F_pp + (1-a_Fs) * F_skin) * (C_kidney_1 / PC_kidney_1) 
  	                - Ke_urine_t_1 * Q_kidney_1)
  	
  	dQ_GIT_1    = ( Ku_t_1 * Q_lumen_GIT_1 +  F_GIT*(C_art_1 - C_GIT_1/PC_GIT_1))
  	
    # Chemical kinetic in  aquarium water
    dQ_water_1 = (dQ_excret_1 - dQ_elim_water_1 - dQ_admin_gills_1)

    
    
    # Excretion
    dQ_feces_2        = Q_lumen_GIT_2 * Ke_feces_t_2
    dQ_excret_gills_2 = Kx_2 * (C_ven_2 * Unbound_fraction_2 / PC_blood_water_2)
    dQ_bile_2         = Ke_bile_t_2 * C_liver_2  - (Q_bile_2 * K_BG_2)
    dQ_urine_2_cplxed = k_cplx * C_urine_1_neutral * C_urine_2_neutral  *molar_mass_2
    dQ_urine_2        = Ke_urine_t_2 * Q_kidney_2 - dQ_urine_2_cplxed# initialized by scenario for urine discharge
    dQ_urine_cum_2    = Ke_urine_t_2 * Q_kidney_2 - dQ_urine_2_cplxed# not initialized 
    dQ_excret_2       = dQ_excret_gills_2 + dQ_urine_cum_2 + dQ_feces_2 
    
    
    # Quantity absorbed : differentials in microg/d
    dQ_admin_gills_2 = Kx_2 * C_water_2         ###Gills
    dQ_lumen_GIT_2   = ( - Ku_t_2 * Q_lumen_GIT_2
                       - Q_lumen_GIT_2 * Ke_feces_t_2
                       + Q_bile_2 * K_BG_2)  ###GIT
    dQ_admin_GIT_2   = 0
    
    # Metabolism
    dQ_met_plasma_2  = ifelse ((Q_ven_2 > rate_plasma_sc_2), rate_plasma_sc_2, Q_ven_2)
    
    dQ_met_liver_2    = ifelse ( is.na(Cl_liver_2),
                                 ( ( Vmax_sc_2 *(C_liver_2/PC_liver_2) )/(Km_2 + C_liver_2/PC_liver_2) ), 
                                 ( Cl_liver_sc_2 * C_liver_2 / PC_liver_2) )
    
    dQ_met_2 = dQ_met_plasma_2 + dQ_met_liver_2
    
    
    # Blood quantity
    dQ_art_2    = ( F_card * C_ven_2 - F_fat * C_art_2 - F_rp * C_art_2 - F_pp * C_art_2
                    - F_liver  * C_art_2 - F_kidney * C_art_2   - F_GIT * C_art_2
                    - F_gonads * C_art_2  - F_skin   * C_art_2 - F_brain  * C_art_2 )
    
    dQ_ven_2    = (F_brain * C_brain_2/PC_brain_2
                   + (F_liver + F_rp + F_gonads + F_GIT ) * C_liver_2/PC_liver_2
                   +  F_fat   * C_fat_2/PC_fat_2
                   + (F_kidney + ((1 - a_Fpp) * F_pp) + ((1 - a_Fs) * F_skin)) * (C_kidney_2 / PC_kidney_2)
                   + a_Fpp * F_pp  * (C_pp_2 / PC_pp_2) 
                   + a_Fs * F_skin * (C_skin_2 / PC_skin_2)
                   - F_card * C_ven_2  
                   + dQ_admin_gills_2 - dQ_excret_gills_2
                   - dQ_met_plasma_2)
    
    # Quantity in tissues 
    dQ_gonads_2 = F_gonads*(C_art_2 - C_gonads_2/PC_gonads_2)
    dQ_fat_2    = F_fat   *(C_art_2 - C_fat_2/PC_fat_2)
    dQ_rp_2     = F_rp    *(C_art_2 - C_rp_2/PC_rp_2)
    dQ_pp_2     = F_pp    *(C_art_2 - C_pp_2/PC_pp_2)
    dQ_brain_2  = F_brain *(C_art_2 - C_brain_2/PC_brain_2)
    dQ_skin_2   = F_skin*(C_art_2 - C_skin_2/PC_skin_2)
    
    dQ_liver_2  =  ( F_liver * C_art_2  
                     + F_rp *(C_rp_2/PC_rp_2)
                     + F_GIT *(C_GIT_2/PC_GIT_2)
                     + F_gonads*(C_gonads_2/PC_gonads_2)
                     - ( F_liver + F_rp + F_GIT + F_gonads  ) *(C_liver_2/PC_liver_2)  
                     - (Ke_bile_t_2  * Q_liver_2) - dQ_met_liver_2 )
    
    dQ_kidney_2 = ( F_kidney * C_art_2 
                    + (1-a_Fpp) * F_pp * (C_pp_2 / PC_pp_2) 
                    + (1-a_Fs) * F_skin * (C_skin_2 / PC_skin_2) 
                    - (F_kidney + (1-a_Fpp) * F_pp + (1-a_Fs) * F_skin) * (C_kidney_2 / PC_kidney_2) 
                    - Ke_urine_t_2 * Q_kidney_2)
    
    dQ_GIT_2    = ( Ku_t_2 * Q_lumen_GIT_2 +  F_GIT*(C_art_2 - C_GIT_2/PC_GIT_2))
    
    # Chemical kinetic in  aquarium water
    dQ_water_2 = (dQ_excret_2 - dQ_elim_water_2 - dQ_admin_gills_2)    
    
    
    
    dQ_cplx = k_cplx * C_urine_2_neutral * C_urine_1_neutral #*(molar_mass_1 + molar_mass_2)
    dQ_crystal = k_crystal * (1 / (1 + (solubility_cplx/((Q_cplx-Q_crystal)/V_urine))^100)) * (Q_cplx-Q_crystal)
    
    # Mass-balance
  			 
	Q_Body_1      = (Q_art_1 + Q_ven_1 + Q_bile_1 + Q_liver_1 + Q_gonads_1 + Q_brain_1 + Q_fat_1 + Q_skin_1 + Q_kidney_1 + Q_GIT_1 + Q_pp_1 + Q_rp_1 ) 
	Q_admin_tot_1 = Q_admin_gills_1 + ivQuantity_1 - Q_lumen_GIT_1 + Q_admin_GIT_1  # amount entering body
	Q_elim_tot_1  = Q_met_1 + Q_excret_1 
	Mass_Bal_1    = Q_admin_tot_1 - Q_Body_1 - Q_elim_tot_1
	Mass_Bal_Sys_1 = (Q_admin_tot_1 - Q_admin_gills_1) - Q_Body_1 - ( Q_elim_tot_1 - Q_excret_1) - Q_water_1 - Q_elim_water_1							
	Q_Body_2      = (Q_art_2 + Q_ven_2 + Q_bile_2 + Q_liver_2 + Q_gonads_2 + Q_brain_2 + Q_fat_2 + Q_skin_2 + Q_kidney_2 + Q_GIT_2 + Q_pp_2 + Q_rp_2 ) 
	Q_admin_tot_2 = Q_admin_gills_2 + ivQuantity_2 - Q_lumen_GIT_2 + Q_admin_GIT_2 # amount entering body
	Q_elim_tot_2  = Q_met_2 + Q_excret_2 
	Mass_Bal_2    = Q_admin_tot_2 - Q_Body_2 - Q_elim_tot_2
	Mass_Bal_Sys_2 = (Q_admin_tot_2 - Q_admin_gills_2) - Q_Body_2 - ( Q_elim_tot_2 - Q_excret_2) - Q_water_2 - Q_elim_water_2							
	
    
    list("Q"=c(dQ_water_1, dL, dV_urine,
               dQ_art_1,  dQ_ven_1,  
               dQ_brain_1, dQ_fat_1,  dQ_GIT_1,  dQ_lumen_GIT_1, dQ_gonads_1, 
               dQ_kidney_1, dQ_liver_1, dQ_skin_1, dQ_rp_1, dQ_pp_1,
               dQ_admin_gills_1, dQ_admin_GIT_1,
               dQ_met_plasma_1, dQ_met_liver_1, dQ_met_1, dQ_elim_water_1,
               dQ_excret_1, dQ_feces_1, dQ_excret_gills_1, dQ_bile_1, dQ_urine_1, dQ_urine_cum_1,
               dQ_water_2,
               dQ_art_2,  dQ_ven_2,  
               dQ_brain_2, dQ_fat_2,  dQ_GIT_2,  dQ_lumen_GIT_2, dQ_gonads_2, 
               dQ_kidney_2, dQ_liver_2, dQ_skin_2, dQ_rp_2, dQ_pp_2,
               dQ_admin_gills_2, dQ_admin_GIT_2,
               dQ_met_plasma_2, dQ_met_liver_2, dQ_met_2, dQ_elim_water_2,
               dQ_excret_2, dQ_feces_2, dQ_excret_gills_2, dQ_bile_2, dQ_urine_2, dQ_urine_cum_2, dQ_crystal, dQ_cplx, dQ_urine_1_cplxed, dQ_urine_2_cplxed), # derivatives
         
         
         c( C_water_1 = C_water_1,
            C_art_1 = C_art_1,       C_ven_1 = C_ven_1, 
            C_brain_1 = C_brain_1,   C_fat_1 = C_fat_1,      C_GIT_1 = C_GIT_1, C_gonads_1 = C_gonads_1,
            C_kidney_1 = C_kidney_1, C_liver_1 = C_liver_1,  C_skin_1 = C_skin_1, 
            C_rp_1    = C_rp_1,      C_pp_1 = C_pp_1, C_urine_1 = C_urine_1, C_tot_1 = C_tot_1,
            C_water_2 = C_water_2,
            C_art_2 = C_art_2,       C_ven_2 = C_ven_2, 
            C_brain_2 = C_brain_2,   C_fat_2 = C_fat_2,      C_GIT_2 = C_GIT_2, C_gonads_2 = C_gonads_2,
            C_kidney_2 = C_kidney_2, C_liver_2 = C_liver_2,  C_skin_2 = C_skin_2, 
            C_rp_2    = C_rp_2,      C_pp_2 = C_pp_2, C_urine_2 = C_urine_2, C_tot_2 = C_tot_2,
            C_urine_1_neutral = C_urine_1_neutral, C_urine_2_neutral = C_urine_2_neutral,
            C_urine_cplx = C_urine_cplx, C_urine_crystal = C_urine_crystal, 
            dQ_urine_1=dQ_urine_1, dQ_urine_2=dQ_urine_2, dQ_crystal=dQ_crystal, dQ_cplx=dQ_cplx, dQ_urine_1_cplxed=dQ_urine_1_cplxed, dQ_urine_2_cplxed=dQ_urine_2_cplxed),
         
         c( V_water = V_water,
            V_art = V_art,  V_ven = V_ven, 
            V_brain = V_brain, V_fat = V_fat, V_GIT = V_GIT,  V_gonads= V_gonads, 
            V_kidney = V_kidney, V_liver = V_liver, V_skin = V_skin, 
            V_rp  = V_rp,  V_pp = V_pp),
         
         c(V_bal = V_bal, 
           F_bal = F_bal, 
           Q_admin_tot_1 = Q_admin_tot_1, 
           Q_elim_tot_1  = Q_elim_tot_1, 
           Q_Body_1 = Q_Body_1, 
           Mass_Bal_1 = Mass_Bal_1,
           Mass_Bal_Sys_1 =Mass_Bal_Sys_1,
           Q_admin_tot_2 = Q_admin_tot_2, 
           Q_elim_tot_2  = Q_elim_tot_2, 
           Q_Body_2 = Q_Body_2, 
           Mass_Bal_2 = Mass_Bal_2,
           Mass_Bal_Sys_2 =Mass_Bal_Sys_2),	   
         
         
         "BW"      = BW,
         "F_card"  = F_card,
         "F_water" = F_water,
         "Kx_1"      = Kx_1,
         "Kx_2"      = Kx_2)
      }) }
