### Parameterisation for PBPK model male rainbow trout #####
# 10/2017
# A. Grech, C.Tebby, C. Brochot, R. Beaudouin.
# 
##############################

##############################
### Units:
###
# Quantity          microg
# Volumes:          mL
# Time:             d
# Flows:            mL/d
# Concentrations:   microg/mL
# Vmax:             microg/d/ mL Liver
# Km:               microg/mL
# Masses:           g
# Lenght:           mm
# Temperature:      Celsius
# Ventilation rate: mL/d

# Density of each tissue is considered equal to 1

###############################

library("deSolve")


#===============================================
# source("PBTK_model.r")
# source("PBTK_PC_QSAR_function.r")
#===============================================


#===============================================
# (II.) Model integration
#===============================================

PBPK.RT.M_mixture_pKa_kidney_BW = function(
  #===============================================
  # (II.1) Parameters
  #===============================================
  
  # Physiological parameters
  Bw_i       = NULL    ,  # Body weight initial (g fresh weight)
  Bw_Fcard_ref= 270.1  ,  # Body weight of reference for F_card from 
  Bw_VO2_ref = 1000    ,  # Body weight of reference for VO2 from Elliot experiments 
  DEB_v      = 0.38    ,  # Energy conductance (mm/d) (DEB model parameter)
  DEB_g      = 0.196   ,  # Energy investment ratio (SU) (DEB model parameter)
  DEB_KM     = 0.027   ,  # Somatic maintenance rate coefficient (1/d) (DEB model parameter)
  DEB_EHm    = 452     ,  # Energy at State of maturity at metamorphosis (J)
  DEB_EHb    = 52      ,  # Energy at State of maturity at birth (J)
  DEB_shape  = 0.113   ,
  a_BW_L     = 0.0051  ,  # a relation BW(g)=F(L(cm)) 
  b_BW_L     = 3.3513  ,  # b relation BW(g)=F(L(cm))
  
  # Environmental condition
  Temperature  = 10   ,    # c
  TA           = 6930 ,    # Arrhenius temperature  in Kelvin
  TR_DEB       = 293.65,   # (Kelvin)
  TR_Fcard     = 279.15,   # (Kelvin)
  TR_VO2       = 283.15,   # (Kelvin)
  f_cst        = 1    ,    # food level 1 = ad-libitum, 0= starvation
  V_water      = 1000 ,    # Volume of aquarium (mL)
  
  # Effective respiratory volume & cardiac output  
  F_card_ref  = 28.5,  # reference cardiac output (mL/min/g): F_card_ref = mL/min/g --> F_card_ref * (60*24) = mL/d/g
  V_O2_ref    = 3.26, # reference oxygen comsuption rate (mg O2/d/g), determined by visual fitting from Elliot, 1969 experiments
  O2_EE       = 0.71, # Oxygen extraction efficiency of 71% proposed by Erickson, 1990
  Sat         = 0.90, # dissolved oxygen saturation of 90% proposed by Erickson, 1990
  frac_art_ven = 1/3, # fraction of arterial blood 
  
  sc_blood  = 0.0527, # volume scaling factor : fraction of BW (%)
  sc_gonads = 0.018 ,
  sc_brain  = 0.0049,
  sc_liver  = 0.0146,   
  sc_fat    = 0.0797,
  sc_skin   = 0.10  ,
  sc_GIT    = 0.099 ,
  sc_kidney = 0.0076,
  sc_rp     = 0.0257, 

  sc_pp     = (1 -  sc_blood - sc_gonads - sc_brain - sc_liver - sc_fat 
               -  sc_skin - sc_GIT - sc_kidney -sc_rp),
  
  frac_gonads =0.0138  ,  # Fraction of arterial blood flow
  frac_brain  =0.018   , 
  frac_liver  =0.0158  , 
  frac_fat    =0.0059  , 
  frac_skin   =0.0570  , 
  frac_GIT    =0.1759  , 
  frac_kidney =0.0817  , 
  frac_rp     =0.0952  ,
  
  frac_pp     = (1 - frac_gonads - frac_brain - frac_liver - frac_fat 
                 - frac_skin - frac_GIT -  frac_kidney - frac_rp),

  # Exposure quantity (microg)
  WaterQuantity_1  = 0, 
  IngestQuantity_1 = 0, 
  ivQuantity_1     = 0,
  WaterQuantity_2  = 0, 
  IngestQuantity_2 = 0, 
  ivQuantity_2     = 0,
  
  # Chemical parameters 
  log_Kow_1        = NULL , #
  Unbound_fraction_1 = 1, # in blood. between 0 and 1. Limits excretion by gills.
  molar_mass_1 = NULL,
  pKa_1 = NULL,
  log_Kow_2        = NULL , #
  Unbound_fraction_2 = 1, # in blood. between 0 and 1. Limits excretion by gills.
  molar_mass_2 = NULL,
  pKa_2 = NULL,
  
  Ratio_blood_plasma_1 = 1, # blood/plasma global equilibrium (hemtocrite, fu, ...)
  Ratio_blood_plasma_2 = 1, # blood/plasma global equilibrium (hemtocrite, fu, ...)
  
  # Organs composition
  water_liver = 0.746   , # relative value (%)
  water_brain = 0.75    ,
  water_gonads= 0.66    , #female value
  water_fat   = 0.05    ,
  water_skin  = 0.667   ,
  water_GIT   = 0.582   , 
  water_kidney= 0.789   ,
  water_rp    = 0.5293  , # value of zebrafish model
  water_pp    = 0.769   , # muscle value
  

  lipids_liver = 0.045 , # relative value (%)
  lipids_brain = 0.073 ,
  lipids_gonads= 0.0563 , #female value
  lipids_fat   = 0.942 ,
  lipids_skin  = 0.029 ,
  lipids_GIT   = 0.288 ,
  lipids_kidney= 0.052 ,
  lipids_rp    = 0.0677 , # value of zebrafish model
  lipids_pp    = 0.03  , # muscle value
  
  PC_bw_1 = NULL,
  PC_l_1 = NULL,
  PC_go_1 = NULL,  
  PC_b_1 = NULL, 
  PC_f_1 = NULL,
  PC_s_1 = NULL,
  PC_gi_1 = NULL,   
  PC_k_1 = NULL, 
  PC_r_1 = NULL, 
  PC_p_1 = NULL, 
  PC_bw_2 = NULL,
  PC_l_2 = NULL,
  PC_go_2 = NULL,  
  PC_b_2 = NULL, 
  PC_f_2 = NULL,
  PC_s_2 = NULL,
  PC_gi_2 = NULL,   
  PC_k_2 = NULL, 
  PC_r_2 = NULL, 
  PC_p_2 = NULL, 
  
  a_Fpp = 0.4, # Fraction of PPT blood going to venous
  a_Fs  = 0.1, # Fraction of skin blood going to venous
  
  #Oral absorption 
  Ku_1       = 0,   # Diffusion coefficient 
  frac_abs_1 = 0,   # Absorption fraction
  Ku_2       = 0,   # Diffusion coefficient 
  frac_abs_2 = 0,   # Absorption fraction
  
  #Metabolism
  Km_1   = NULL , # microg/ml
  Vmax_1 = NA , # microg/d/mL liver
  Cl_liver_1   = NA , # mL/g/d
  rate_plasma_1  = 0, # mg/g/d
  Km_2   = NULL , # microg/ml
  Vmax_2 = NA , # microg/d/mL liver
  Cl_liver_2   = NA , # mL/g/d
  rate_plasma_2  = 0, # mg/g/d
  
  #Excretion
  Ke_bile_1  = 0, # 1/d
  Ke_urine_1 = 0, # 1/d
  Ke_water_1 = 0, # 1/d
  K_BG_1     = 0, # 1/d chemical rate constant from bile to GIT_lumen # 0 : no bile excretion: accumulation in bilary vesicule # 1E12 : Complete bile excretion in GIT_lumen
  Ke_bile_2  = 0, # 1/d
  Ke_urine_2 = 0, # 1/d
  Ke_water_2 = 0, # 1/d
  K_BG_2     = 0, # 1/d chemical rate constant from bile to GIT_lumen # 0 : no bile excretion: accumulation in bilary vesicule # 1E12 : Complete bile excretion in GIT_lumen
  
  #Feces and urination
  Ke_feces_1   = 0.83 , # 1/d estiamted from Nichols  et al. 2004
  Ke_feces_2   = 0.83 , # 1/d estiamted from Nichols  et al. 2004
  urine_rate = 1.2e-03*60*24/29.82, # V_burst = 1.2 mL.kg-1 every 29.82 minutes proposed by Curtis 1991 --> 1.2e-03 mL.g BW-1 
  urination_interval = NULL  ,    # 30min proposed by Curtis 1991 --> 30/60/24hr
  
  # temps
  Times  = NULL,       # days
  Time_end_exposure = max(Times), # days
  period = NULL,       # days between two doses
  frac_renewed    = NULL, # fraction of the water of the aquaria renewed
  time_final_dose_1 = NULL,
  time_first_dose_1 = NULL,
  time_final_dose_2 = NULL,
  time_first_dose_2 = NULL,
  # interaction
  k_cplx = 0,
  k_crystal = 10000,
  k_crystal_trapped=0,
  solubility_cplx = 3.1e-2 ,#*(129+126), # 31micromol.L-1 = 3.1e-2µmol.mL-1 = 0.0 for Mel-Cya
  pH_kidney = 7
  
){
  
  
  #===============================================
  # (I.) Vectors of parameters
  #=============================================== 
  
  # Physiological parameters
  parms_physio <- c (# DEB model parameters
    "Bw_i" = Bw_i, "Bw_VO2_ref" = Bw_VO2_ref, "Bw_Fcard_ref" = Bw_Fcard_ref, "DEB_v" = DEB_v, "DEB_g" = DEB_g, "DEB_KM" = DEB_KM,
    "DEB_EHm" = DEB_EHm,  "DEB_EHb" = DEB_EHb,
    "DEB_shape"  = DEB_shape   , "a_BW_L" = a_BW_L  ,  "b_BW_L" = b_BW_L,
    
    # cardiac ouptut & respiratory parameters
    "F_card_ref" = F_card_ref,  "O2_EE" = O2_EE, "Sat" = Sat, "V_O2_ref" = V_O2_ref, 
	"frac_art_ven" = frac_art_ven, 
    
    # relative flux to cardiac ouptut 
    "frac_liver" = frac_liver, "frac_gonads"= frac_gonads, "frac_brain"  = frac_brain, 
    "frac_fat"   = frac_fat ,   "frac_skin"   = frac_skin,
    "frac_GIT" = frac_GIT , "frac_kidney" = frac_kidney,    "frac_rp"    = frac_rp, 
    "frac_pp"    = frac_pp, 
    
    # relative weight to BW
    "sc_GIT"    = sc_GIT,    "sc_skin"  = sc_skin,   "sc_blood"   = sc_blood,  
    "sc_liver"  = sc_liver,  "sc_gonads"= sc_gonads,   "sc_fat"   = sc_fat,
    "sc_brain"  = sc_brain,  "sc_rp"    = sc_rp,       "sc_pp"    = sc_pp,     
    "sc_kidney" = sc_kidney,
    
    # urination
    "urine_rate" = urine_rate, "urination_interval" = urination_interval
  )
  
  # Partition coefficients : QSAR model 
  parms_PC_1  = PC_qsar_model(log_Kow =log_Kow_1, PC_bw = PC_bw_1,
                              water_liver = water_liver  , lipids_liver  = lipids_liver ,   PC_l  = PC_l_1,
                              water_gonads= water_gonads , lipids_gonads = lipids_gonads,   PC_go = PC_go_1,
                              water_brain = water_brain  , lipids_brain  = lipids_brain,    PC_b  = PC_b_1,
                              water_fat   = water_fat    , lipids_fat    = lipids_fat,      PC_f  = PC_f_1,
                              water_skin  = water_skin   , lipids_skin   = lipids_skin,     PC_s  = PC_s_1,
                              water_GIT   = water_GIT    , lipids_GIT    = lipids_GIT,      PC_gi = PC_gi_1,
                              water_kidney= water_kidney , lipids_kidney = lipids_kidney,   PC_k  = PC_k_1,
                              water_rp    = water_rp     , lipids_rp     = lipids_rp,       PC_r  = PC_r_1,
                              water_pp    = water_pp     ,  lipids_pp     = lipids_pp,      PC_p  = PC_p_1)
  parms_PC_2  = PC_qsar_model(log_Kow =log_Kow_2, PC_bw = PC_bw_2,
                              water_liver = water_liver  , lipids_liver  = lipids_liver ,   PC_l  = PC_l_2,
                              water_gonads= water_gonads , lipids_gonads = lipids_gonads,   PC_go = PC_go_2,
                              water_brain = water_brain  , lipids_brain  = lipids_brain,    PC_b  = PC_b_2,
                              water_fat   = water_fat    , lipids_fat    = lipids_fat,      PC_f  = PC_f_2,
                              water_skin  = water_skin   , lipids_skin   = lipids_skin,     PC_s  = PC_s_2,
                              water_GIT   = water_GIT    , lipids_GIT    = lipids_GIT,      PC_gi = PC_gi_2,
                              water_kidney= water_kidney , lipids_kidney = lipids_kidney,   PC_k  = PC_k_2,
                              water_rp    = water_rp     , lipids_rp     = lipids_rp,       PC_r  = PC_r_2,
                              water_pp    = water_pp     ,  lipids_pp     = lipids_pp,      PC_p  = PC_p_2)
  names(parms_PC_1)<-paste0(names(parms_PC_1), "_1")
  names(parms_PC_2)<-paste0(names(parms_PC_2), "_2")
  
  
  # chemical-dependant. Non relevant parameters can be set to NA
  parms_chemical <- c(# Metabolism
    "Cl_liver_1" = Cl_liver_1, "rate_plasma_1" = rate_plasma_1,
    "Km_1" = Km_1, "Vmax_1" = Vmax_1, 
    "log_Kow_1" = log_Kow_1,
    "pKa_1" = pKa_1,
    "molar_mass_1" = molar_mass_1,
    "Unbound_fraction_1" = Unbound_fraction_1,  "Ratio_blood_plasma_1" = Ratio_blood_plasma_1,
    "Ke_bile_1"= Ke_bile_1, "Ke_urine_1" = Ke_urine_1,  "Ke_water_1" = Ke_water_1, "Ke_feces_1" = Ke_feces_1,  "K_BG_1" = K_BG_1,
    
    # Venous blood flow distribution
    "a_Fpp" = a_Fpp,  "a_Fs"   = a_Fs,
    
    
    # Oral absorption 
    "Ku_1" = Ku_1, "frac_abs_1" = frac_abs_1,
    
    # Metabolism
    "Cl_liver_2" = Cl_liver_2, "rate_plasma_2" = rate_plasma_2,
    "Km_2" = Km_2, "Vmax_2" = Vmax_2, 
    "log_Kow_2" = log_Kow_2,
    "pKa_2" = pKa_2,
    "molar_mass_2" = molar_mass_2,
    "Unbound_fraction_2" = Unbound_fraction_2,  "Ratio_blood_plasma_2" = Ratio_blood_plasma_2,
    "Ke_bile_2"= Ke_bile_2, "Ke_urine_2" = Ke_urine_2,  "Ke_water_2" = Ke_water_2, "Ke_feces_2" = Ke_feces_2,  "K_BG_2" = K_BG_2,
    
    # Oral absorption 
    "Ku_2" = Ku_2, "frac_abs_2" = frac_abs_2, 
    
    # interaction
    "k_cplx" = k_cplx, "k_crystal" = k_crystal, "k_crystal_trapped"= k_crystal_trapped, "solubility_cplx" = solubility_cplx, "pH_kidney" = pH_kidney)					  
  
  
  # exposure parameters 
  parms_exposure <- c(# environmental parameters
    "TA"=TA, "TR_DEB"=TR_DEB, "TR_Fcard"=TR_Fcard, "TR_VO2"=TR_VO2, "f_cst"= f_cst, "V_water" = V_water,
    
    # Exposure quantity
    "IngestQuantity_1" = IngestQuantity_1, 
    "WaterQuantity_1" = WaterQuantity_1, 
    "ivQuantity_1" = ivQuantity_1,
    "IngestQuantity_2" = IngestQuantity_2, 
    "WaterQuantity_2" = WaterQuantity_2, 
    "ivQuantity_2" = ivQuantity_2,
    
    # Exposure time scenario
    "Time_end_exposure" = Time_end_exposure, "period"=period, "time_final_dose_1"=time_final_dose_1, "time_first_dose_1"=time_first_dose_1,  "time_final_dose_2"=time_final_dose_2, "time_first_dose_2"=time_first_dose_2) 
  
  Parameters <-c(parms_physio, c(parms_PC_1, parms_PC_2), parms_chemical, parms_exposure) 
  
  
  #===============================================
  #(II.1) Initial values
  #===============================================
  L0 = ((Bw_i/ a_BW_L) ^ (1/b_BW_L)) * DEB_shape * 10  # g --> cm Ltotale --> Lstruc --> mm
  Initial.Values_BW <- c("L"      = L0)
  
  
  Initial.Values <- c("Q_water_1"= WaterQuantity_1* Bw_i,
                      "L"      = L0, 
                      "V_urine"= urine_rate*Bw_i/(60*24),
                      
                      "Q_art_1"  = 0,  "Q_ven_1"   = ivQuantity_1* Bw_i,
                      
                      "Q_brain_1"= 0, "Q_fat_1"=0, "Q_GIT_1" =0, "Q_lumen_GIT_1" = (IngestQuantity_1 * frac_abs_1)* Bw_i,  
                      "Q_gonads_1"= 0, "Q_kidney_1" =0,  "Q_liver_1"= 0,  
                      "Q_skin_1" =0, "Q_rp_1"=0, "Q_pp_1"=0, 
                      
                      "Q_admin_gills_1"=0,  "Q_admin_GIT_1"=(IngestQuantity_1 * frac_abs_1)* Bw_i, 
                      "Q_met_plasma_1"=0, "Q_met_liver_1"=0, "Q_met_1"=0,  "Q_elim_water_1"=0,
                      "Q_excret_1"=0, "Q_feces_1"=0, "Q_excret_gills_1"=0, "Q_bile_1"=0, "Q_urine_1"=0, "Q_urine_cum_1"=0,
                      
                      "Q_water_2"= WaterQuantity_2* Bw_i, 
                      "Q_art_2"  = 0,  "Q_ven_2"   = ivQuantity_2* Bw_i,
                      
                      "Q_brain_2"= 0, "Q_fat_2"=0, "Q_GIT_2" =0, "Q_lumen_GIT_2" = (IngestQuantity_2 * frac_abs_2)* Bw_i,  
                      "Q_gonads_2"= 0, "Q_kidney_2" =0,  "Q_liver_2"= 0,  
                      "Q_skin_2" =0, "Q_rp_2"=0, "Q_pp_2"=0, 
                      
                      "Q_admin_gills_2"=0,  "Q_admin_GIT_2"=(IngestQuantity_2 * frac_abs_2)* Bw_i, 
                      "Q_met_plasma_2"=0, "Q_met_liver_2"=0, "Q_met_2"=0,  "Q_elim_water_2"=0,
                      "Q_excret_2"=0, "Q_feces_2"=0, "Q_excret_gills_2"=0, "Q_bile_2"=0, "Q_urine_2"=0, "Q_urine_cum_2"=0,
                      "Q_crystal"=0, "Q_cplx"=0, "Q_crystal_kidney"=0)
  
  
  #===============================================
  #(II.2) Environmental and biological scenario
  #===============================================
  
  # Temperature scenarii
  if( length (Temperature) > 1) {
    times = seq(0, length(Temperature)-1, 1)
    import = Temperature
  } else {
    times = Times
    import = rep(Temperature, length(times))}
  
  Scenario = data.frame(times = times, import = import)
  Temperature.Scenario = approxfun(Scenario$times, Scenario$import, rule = 2)
  
  # scenario for urine discharge ###################################################################
  if (!is.null(urination_interval)){
    events_urine <- list(data = rbind(data.frame(var = c("V_urine"), 
                                                 time = seq(Times[1], rev(Times)[1] , by=urination_interval), 
                                                 value = 0.01, # 1% of the V_burst
                                                 method = c("multiply")),
                                      data.frame(var = c("Q_urine_1"), 
                                                 time = seq(Times[1], rev(Times)[1] , by=urination_interval), 
                                                 value = 0.01, 
                                                 method = c("multiply")),
                                      data.frame(var = c("Q_urine_2"), 
                                                 time = seq(Times[1], rev(Times)[1] , by=urination_interval), 
                                                 value = 0.01, 
                                                 method = c("multiply"))))
  }else{ events_urine <- NULL }
  
  #===============================================
  #(II.3) Exposure scenario :   events_repeated
  #===============================================
  events_repeated_f <- NULL
  
  # repeated dose scenario for oral bolus
  if (!is.null(period) & IngestQuantity_1!=0 ) {
    
    # no stop before the end of the experiement
    if (is.null(time_final_dose_1)){ time_final_dose_1 <- floor(max(Times)/period)*period}
    if (is.null(time_final_dose_2)){ time_final_dose_2 <- floor(max(Times)/period)*period}
    
    # First dose NOT at t0 of the experiment
    if (!is.null(time_first_dose_1)) { Initial.Values["Q_admin_GIT_1"]<-0 ; Initial.Values["Q_lumen_GIT_1"]<-0 }
    if (!is.null(time_first_dose_2)) { Initial.Values["Q_admin_GIT_2"]<-0 ; Initial.Values["Q_lumen_GIT_2"]<-0 }
    
    # First dose at t0 of the experiment
    if (is.null(time_first_dose_1)){ time_first_dose_1 = period }
    if (is.null(time_first_dose_2)){ time_first_dose_2 = period }
    
    Body_Weight_1 <- ode(times = seq(time_first_dose_1, time_final_dose_1 , by=period), 
                         func  = BW.model, 
                         y     = Initial.Values_BW , 
                         parms = Parameters,
                         input.T = Temperature.Scenario,
                         method="lsodes")[, "BW"]
    Body_Weight_2 <- ode(times = seq(time_first_dose_2, time_final_dose_2 , by=period), 
                         func  = BW.model, 
                         y     = Initial.Values_BW , 
                         parms = Parameters,
                         input.T = Temperature.Scenario,
                         method="lsodes")[, "BW"]
    
    # events : a list with a data frame for each compartment --> Cpt name / Time / Dose / method
    events_repeated_f <- list(data = rbind(data.frame(var = c("Q_lumen_GIT_1"), 
                                                    time = seq(time_first_dose_1, time_final_dose_1 , by=period), 
                                                    value = as.numeric(c(parms_chemical["frac_abs_1"]*parms_exposure["IngestQuantity_1"]*Body_Weight_1)), 
                                                    method = c("add")),
                                         data.frame(var = c("Q_admin_GIT_1"), 
                                                    time = seq(time_first_dose_1, time_final_dose_1 , by=period), 
                                                    value = as.numeric(c(parms_chemical["frac_abs_1"]*parms_exposure["IngestQuantity_1"]*Body_Weight_1)), 
                                                    method = c("add")),
                                         data.frame(var = c("Q_lumen_GIT_2"), 
                                                    time = seq(time_first_dose_2, time_final_dose_2 , by=period), 
                                                    value = as.numeric(c(parms_chemical["frac_abs_2"]*parms_exposure["IngestQuantity_2"]*Body_Weight_2)), 
                                                    method = c("add")),
                                         data.frame(var = c("Q_admin_GIT_2"), 
                                                    time = seq(time_first_dose_2, time_final_dose_2 , by=period), 
                                                    value = as.numeric(c(parms_chemical["frac_abs_2"]*parms_exposure["IngestQuantity_2"]*Body_Weight_2)), 
                                                    method = c("add")))) # uses Initial.Values for the first bolus
  } 
  
  # repeated dose scenario for water exposure ######################################################
  
  events_repeated_w <- NULL
  
  
  if (!is.null(period) & WaterQuantity_1!=0 ) {
    
    # no stop before the end of the experiement
    if (is.null(time_final_dose_1)){ time_final_dose_1 <- floor(max(Times)/period)*period}
    if (is.null(time_final_dose_2)){ time_final_dose_2 <- floor(max(Times)/period)*period}
    
    # First dose NOT at t0 of the experiment
    if (!is.null(time_first_dose_1)) { Initial.Values["Q_admin_GIT_1"]<-0 ; Initial.Values["Q_lumen_GIT_1"]<-0 }
    if (!is.null(time_first_dose_2)) { Initial.Values["Q_admin_GIT_2"]<-0 ; Initial.Values["Q_lumen_GIT_2"]<-0 }
    
    # First dose at t0 of the experiment
    if (is.null(time_first_dose_1)){ time_first_dose_1 = period }
    if (is.null(time_first_dose_2)){ time_first_dose_2 = period }
    
    # events : a list with a data frame for each compartment --> Cpt name / Time / Dose / method
    events_repeated_w <- list(data = rbind(data.frame(var = c("Q_water_1"), 
                                                      time  = seq(time_first_dose_1, time_final_dose_1 , by=period), 
                                                      value = (1-frac_renewed), 
                                                      method = c("multiply")),
                                           data.frame(var = c("Q_water_1"), 
                                                      time =  0.0000001+seq(time_first_dose_1, time_final_dose_1 , by=period), 
                                                      value = as.numeric( parms_exposure["WaterQuantity_1"]* frac_renewed), 
                                                      method = c("add")),
                                           data.frame(var = c("Q_water_2"), 
                                                      time  = seq(time_first_dose_2, time_final_dose_2 , by=period), 
                                                      value = (1-frac_renewed), 
                                                      method = c("multiply")),
                                           data.frame(var = c("Q_water_2"), 
                                                      time =  0.0000001+seq(time_first_dose_2, time_final_dose_2 , by=period), 
                                                      value = as.numeric( parms_exposure["WaterQuantity_2"]* frac_renewed), 
                                                      method = c("add")),
                                           data.frame(var = c("Q_water_1"),
                                                      time  = Time_end_exposure,
                                                      value = 0,
                                                      method = c("multiply")),
                                           data.frame(var = c("Q_water_2"),
                                                      time  = Time_end_exposure,
                                                      value = 0,
                                                      method = c("multiply")),
                                           
                                           # In depuration phase, water renewal
                                            data.frame(var = c("Q_water_1"),
                                                       time  = 0.0000001+seq(Time_end_exposure, max(Times) , by=period),
                                                       value = (1-frac_renewed),
                                                       method = c("multiply")),
                                           data.frame(var = c("Q_water_2"),
                                                      time  = 0.0000001+seq(Time_end_exposure, max(Times) , by=period),
                                                      value = (1-frac_renewed),
                                                      method = c("multiply"))))    
  }
  if (is.null(period)){
    events_repeated_w <- list(data = rbind(data.frame(var = c("Q_water_1"), 
                                                      time  = Time_end_exposure, 
                                                      value = 0, 
                                                      method = c("multiply")),
                                           data.frame(var = c("Q_water_2"), 
                                                      time  = Time_end_exposure, 
                                                      value = 0, 
                                                      method = c("multiply"))))
  }
  
  
  events<-list(data = rbind(events_repeated_f[[1]], events_repeated_w[[1]], events_urine[[1]]))
  
  
  #===============================================
  # (III) Numerical resolution and post-calcul
  #===============================================
  
  out <- ode(times = Times, 
             func  = PBPK.model_T_mixture_pKa_kidney, 
             y     = Initial.Values , 
             parms = Parameters,
             input.T = Temperature.Scenario,
             method="lsodes", 
             events = events,
             rtol = 1e-12, 
             atol=1e-8)
  
  PC_1 = parms_PC_1
  PC_2 = parms_PC_2
  
  return( list("Sim"=out, "PC"=c(PC_1, PC_2), "Length" = out[,"L"] / DEB_shape * 1/10 ) ) # Length (cm)
}
